##  SBOM Naming Convention
The default naming convention for SBOMs must follow the below format:
```
<microservice-name-as-in-the-manifest>-sbom
```

  * Supported characters include:
    * Alphanumeric symbols
    * Special characters: dash (-), underscore (_), and slash (/)
  * Regular expressions are not supported.


For example, the file name of the SBOM artifact for the ai-assistant microservice is ai-assistant-sbom.
